==> amarok_2.9.0.orig.tar.xz: amarok-2.9.0/tests/core-impl/collections/db/sql/TestSqlArtist.h <==
/****************************************************************************************
 * Copyright (c) 2009 Maximilian Kossick <maximilian.kossick@googlemail.com>       *
 *                                                                                      *
 * This program is free software; you can redistribute it and/or modify it under        *
 * the terms of the GNU General Public License as published by the Free Software        *
 * Foundation; either version 2 of the License, or (at your option) any later           *
 * version.                                                                             *
 *                                                                                      *
 * This program is distributed in the hope that it will be useful, but WITHOUT ANY      *
 * WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A      *
 * PARTICULAR PURPOSE. See the GNU General Public License for more details.             *
 *                                                                                      *
 * You should have received a copy of the GNU General Public License along with         *
 * this program.  If not, see <http://www.gnu.org/licenses/>.                           *
 ****************************************************************************************/

#ifndef TESTSQLARTIST_H
#define TESTSQLARTIST_H

#include <QtTest/QtTest>
#include <KTempDir>

class MySqlEmbeddedStorage;

namespace Collections {
    class SqlCollection;
}

class TestSqlArtist : public QObject
{
    Q_OBJECT
public:
    TestSqlArtist();

private slots:
    void initTestCase();
    void cleanupTestCase();

    void init();
    void cleanup();

    void testSortableName();

private:
    Collections::SqlCollection *m_collection;
    MySqlEmbeddedStorage *m_storage;
    KTempDir *m_tmpDir;

    public:
};

#endif // TESTSQLARTIST_H

==> amarok-2.9.71.tar.xz: amarok-2.9.71/tests/core-impl/collections/db/sql/TestSqlArtist.h <==
/****************************************************************************************
 * Copyright (c) 2009 Maximilian Kossick <maximilian.kossick@googlemail.com>       *
 *                                                                                      *
 * This program is free software; you can redistribute it and/or modify it under        *
 * the terms of the GNU General Public License as published by the Free Software        *
 * Foundation; either version 2 of the License, or (at your option) any later           *
 * version.                                                                             *
 *                                                                                      *
 * This program is distributed in the hope that it will be useful, but WITHOUT ANY      *
 * WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A      *
 * PARTICULAR PURPOSE. See the GNU General Public License for more details.             *
 *                                                                                      *
 * You should have received a copy of the GNU General Public License along with         *
 * this program.  If not, see <http://www.gnu.org/licenses/>.                           *
 ****************************************************************************************/

#ifndef TESTSQLARTIST_H
#define TESTSQLARTIST_H

#include <QSharedPointer>
#include <QtTest>
#include <QTemporaryDir>

class MySqlEmbeddedStorage;

namespace Collections {
    class SqlCollection;
}

class TestSqlArtist : public QObject
{
    Q_OBJECT
public:
    TestSqlArtist();

private Q_SLOTS:
    void initTestCase();
    void cleanupTestCase();

    void init();
    void cleanup();

    void testSortableName();

private:
    Collections::SqlCollection *m_collection;
    QSharedPointer<MySqlEmbeddedStorage> m_storage;
    QTemporaryDir *m_tmpDir;

    public:
};

#endif // TESTSQLARTIST_H
